lplq
=============

ETNA package attached to the paper:

_Alessandro Buccini and Lothar Reichel_
**Software for limited memory restarted ℓp-ℓq minimization methods
using generalized Krylov subspaces**
ETNA Volume 61, Pages 66-91, 2024
[link](https://etna.ricam.oeaw.ac.at/vol.61.2024/pp66-91.dir/pp66-91.pdf)

---

AUTHORS
-------

- Alessandro Buccini,
       University of Cagliari, Italy
- Lothar Reichel,
       Kent State University, Kent, USA

> Email: alessandro.buccini@unica.it, reichel@math.kent.edu

---

DESCRIPTION
-----------

This package provides one function capable of solving a large linear discrete
ill-posed problem. Two demos are provided in the package, the first illustrate
the performances of the different selection rules for the regularization
parameters, the second shows a comparison between our proposal and l2-l2/3
shrinkage.

Release: 1.0, June 2024

Programming language: Matlab 9.11 (R2021b)

License: (see license.md)

---

DISCLAIMER
----------

ETNA editors have test run the code, but the reponsibility of the correctness
of the code is with the authors. ETNA is not responsible for any problems the 
code may cause; see the file License.md for details.

---

INSTALLATION
------------

Download and extract the lplq package. To run the Test.m and Test23.m files the
folders @Aclass, @Aclass3, @TVclass, and @TVclass3, must be either in the same
folder or in the path. The files Test.m and Test23.m contain the numerical
examples present in the paper.

---

PACKAGE USE
------------

As long as all necessary files are in the working directory (see above), the
Test.m and Test23.m demos may be executed without entry of additional
information (i.e. the demos are already set-up). For more information, see the
codePrimer.pdf file in this package.

---

PACKAGE STRUCTURE
-----------------

The following is a list with a brief description of the contents of the
lplq package. For a more detailed description see the codePrimer.pdf
file in this package.

* codePrimer.pdf         : A detailed overview of the lplq package
                           contents specifically directed towards the functions
                           provided.
* License.md             : Markdown file containing license for package use. 
* README.md              : This file.
* lplq.m                 : The lplq algorithm for linear discrete ill-posed
                           problems.
* l23Reg.m               : The l2-l2/3 shrinkage algorithm for linear discrete
                           ill-posed problems.
* Test.m                 : A demo to showcase the use of the lplq algorithm 
                           on six examples.
* Test23.m               : A comparison between lplq minimization and the
                           l2-l2/3 
                           shrinkage algorithm
* @Aclass                : A class that implements the blurring operator of b/w
                           images
* @Aclass3               : A class that implements the blurring operator of
                           color images
* @TVclass               : A class that implements the Total Variation operator
                           for b/w images
* @TVclass3              : A class that implements the Total Variation operator
                           for color images
* Cameraman_dataset.mat  : Dataset for the examples
* Peppers_dataset.mat    : Dataset for the examples
* Satellite_dataset.mat  : Dataset for the examples
* Saturn_dataset.mat     : Dataset for the examples
* Tomography_dataset.mat : Dataset for the examples
* Tree_dataset.mat       : Dataset for the examples

---

PACKAGE UPDATES
---------------
Package updates (if available) can be found at:
[link](https://sites.google.com/site/alessandobuccini/home)

