%% Clear workspace
clc
clear
close all
%% Create test case
ch=menu('Select test case:','Cameraman','Peppers','Saturn','Tomography','Tree'); %Menu to select the example
switch ch
    case 1
        load Cameraman_dataset
    case 2
        load Peppers_dataset
    case 3
        load Saturn_dataset
    case 4
        load Tomography_dataset
    case 5
        load Tree_dataset
end
%% Set parameters
switch ch %set the parameters depending on the example chosen
    case 1
        options.p=2;
        options.choiceRule='CV';
        options.majorantType='fixed';
        options.trainingTestNum=3;
    case 2
        options.p=0.8;
        options.choiceRule='GCV';
        options.size=[n1 n2];
    case 3
        options.p=0.8;
        options.choiceRule='MCV';
        options.majorantType='fixed';
        options.trainingTestNum=3;
    case 4
        options.p=2;
        options.choiceRule='RWP';
        options.sizes=[n1 n2];
    case 5
        options.p=2;
        options.choiceRule='DP';
        options.noiseNorm=delta;
end
options.epsilon=1;
options.restart=30;
options.maxIt=500;
if ch<=4
    options.L=TVclass(n1,n2);
else
    options.L=TVclass3(n1,n2);
end
options.xTrue=x_true;
options.waitbar='on';
if ch<4 %Construct the operator for the b/w deblurring problem
    bc='reflexive';
    A=Aclass(PSF,center,bc,n1,n2);
elseif ch==5 %Construct the operator for the color deblurring problem
    bc='reflexive';
    A=Aclass3(PSF,center,PSF,center,PSF,center,mix_channels,bc,n1,n2);
end
%% Recover
tic
[x,outInfo]=lplq(A,b,options);
t=toc;
%% Show results
if ch<4
    figure(1)
    subplot(1,4,1), imshow(reshape(x_true,n1,n2),[]), title('True image','interpreter','latex','fontsize',14)
    subplot(1,4,2), imshow(PSF,[]), title('PSF','interpreter','latex','fontsize',14)
    subplot(1,4,3), imshow(reshape(b,n1,n2),[]), title('Blurred and noisy image','interpreter','latex','fontsize',14)
    subplot(1,4,4), imshow(reshape(x,n1,n2),[]), title('Recovered image','interpreter','latex','fontsize',14)
elseif ch==4
    figure(1)
    subplot(1,3,1), imshow(reshape(x_true,n1,n2),[]), title('True phantom','interpreter','latex','fontsize',14)
    subplot(1,3,2), imshow(reshape(b,numel(b)/length(opt.angles),length(opt.angles)),[]), title('Sinogram','interpreter','latex','fontsize',14)
    subplot(1,3,3), imshow(reshape(x,n1,n2),[]), title('Recovered phantom','interpreter','latex','fontsize',14)
else
    figure(1)
    subplot(1,4,1), imshow(reshape(uint8(x_true),n1,n2,3),[]), title('True image','interpreter','latex','fontsize',14)
    subplot(1,4,2), imshow(padarray(PSF,[3 3],0,'both'),[]), title('PSF','interpreter','latex','fontsize',14)
    subplot(1,4,3), imshow(reshape(uint8(b),n1,n2,3),[]), title('Blurred and noisy image','interpreter','latex','fontsize',14)
    subplot(1,4,4), imshow(reshape(uint8(x),n1,n2,3),[]), title('Recovered image','interpreter','latex','fontsize',14)
end
figure(2)
subplot(1,2,1), semilogy(0:outInfo.iter,outInfo.RRE,'b','linewidth',2), title('RRE','interpreter','latex','fontsize',14)
subplot(1,2,2), semilogy(0:outInfo.iter,outInfo.res,'b','linewidth',2), title('Residual norm','interpreter','latex','fontsize',14)