%% Clear workspace
clc
clear
close all
%% Create test case
load Satellite_dataset
bc='reflexive'; %Select the boundary conditions for the operator
A=Aclass(PSF,center,bc,n1,n2);
%% Set parameters for lp-lq
options.p=2;
options.choiceRule='DP';
options.noiseNorm=delta;
options.epsilon=1;
options.restart=30;
options.maxIt=1000;
options.tol=1e-6;
options.xTrue=x_true;
options.waitbar='on';
nq=10; %number of q to test
q=linspace(0.1,1,nq); 
q=sort([q,2/3]); %ensure that 2/3 is among the tested q
nq=nq+1;
%% Recover with lp-lq
X=zeros(numel(b),nq); %Preallocate the memory for storing all the reconstructions
OUT=cell(nq,1); %Preallocate the memory for storing alle the output structures
t_lplq=zeros(nq,1); %Preallocate the memory for storing all the computational times
RRE_lplq=zeros(nq,1); %Preallocate the memory for storing all the final RREs
for i=1:nq %Run lplq for each q
    options.q=q(i); %use the selected q
    tic
    [x,outInfo]=lplq(A,b,options);
    t_lplq(i)=toc;
    X(:,i)=x;
    OUT{i}=outInfo;
    RRE_lplq(i)=outInfo.RRE(end);
end
%% Set parameters for l2-l2/3 thresholding
nmu=15; %Number of mu to be tested
mu=logspace(-1,2,nmu); %Create the mu
maxit=1000; %Maximum number of iterations
tol=1e-6; %Tollerance for the stopping criterion
%% Recover with l2-l2/3
X23=zeros(numel(x),nmu); %Preallocate memory to store all the computed solutions
RRE23=cell(nmu,1); %Preallocate memory to store all the RRE at each iteration
rre23=zeros(nmu,1); %Preallocate memory to store all the RRE for each mu
res23=zeros(nmu,1); %Preallocate memory to store all the residual norm for each mu
t23=zeros(nmu,1); %Preallocate memory to store all the timings for each mu
for i=1:nmu %run l2-l2/3 for each mu 
    tic
    [x23,RRE]=l23Reg(A,b,mu(i),maxit,tol,x_true);
    t23(i)=toc;
    X23(:,i)=x23;
    RRE23{i}=RRE;
    rre23(i)=RRE(end);
    res23(i)=norm(b-A*x23);
end
idxDP=find(res23<=1.01*delta,1,'last'); %Determine the mu of the DP
[~,idxopt]=min(rre23); %Determine the optimal mu
%% Show results
q23=find(q==2/3);
figure,
semilogy(q,RRE_lplq,'b',q(q23),RRE_lplq(q23),'b*',q,rre23(idxDP)*ones(size(q)),'k--',q,rre23(idxopt)*ones(size(q)),'r:','linewidth',2,'markersize',10)
l=legend('$\ell^p-\ell^q$ minimization','$\ell^p-\ell^q$ minimization, $q=2/3$','$\ell^2-\ell^{2/3}$ (DP)','$\ell^2-\ell^{2/3}$ (Optimal)');
set(l,'Interpreter','latex','fontsize',16);
axis([q(1) q(end) min(RRE_lplq)*0.9 rre23(idxDP)*1.1])
xlabel('q','interpreter','latex','fontsize',16)
ylabel('RRE','interpreter','latex','fontsize',16)